==> autoscaling-1.60.0-sources.jar: software/amazon/awscdk/services/autoscaling/NetworkUtilizationScalingProps.java <==
package software.amazon.awscdk.services.autoscaling;

/**
 * Properties for enabling scaling based on network utilization.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.9.0 (build 5c646d5)", date = "2020-08-19T23:25:23.650Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.autoscaling.$Module.class, fqn = "@aws-cdk/aws-autoscaling.NetworkUtilizationScalingProps")
@software.amazon.jsii.Jsii.Proxy(NetworkUtilizationScalingProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface NetworkUtilizationScalingProps extends software.amazon.jsii.JsiiSerializable, software.amazon.awscdk.services.autoscaling.BaseTargetTrackingProps {

    /**
     * Target average bytes/seconds on each instance.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.Number getTargetBytesPerSecond();

    /**
     * @return a {@link Builder} of {@link NetworkUtilizationScalingProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link NetworkUtilizationScalingProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<NetworkUtilizationScalingProps> {
        private java.lang.Number targetBytesPerSecond;
        private software.amazon.awscdk.core.Duration cooldown;
        private java.lang.Boolean disableScaleIn;
        private software.amazon.awscdk.core.Duration estimatedInstanceWarmup;

        /**
         * Sets the value of {@link NetworkUtilizationScalingProps#getTargetBytesPerSecond}
         * @param targetBytesPerSecond Target average bytes/seconds on each instance. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder targetBytesPerSecond(java.lang.Number targetBytesPerSecond) {
            this.targetBytesPerSecond = targetBytesPerSecond;
            return this;
        }

        /**
         * Sets the value of {@link NetworkUtilizationScalingProps#getCooldown}
         * @param cooldown Period after a scaling completes before another scaling activity can start.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder cooldown(software.amazon.awscdk.core.Duration cooldown) {
            this.cooldown = cooldown;
            return this;
        }

        /**
         * Sets the value of {@link NetworkUtilizationScalingProps#getDisableScaleIn}
         * @param disableScaleIn Indicates whether scale in by the target tracking policy is disabled.
         *                       If the value is true, scale in is disabled and the target tracking policy
         *                       won't remove capacity from the autoscaling group. Otherwise, scale in is
         *                       enabled and the target tracking policy can remove capacity from the
         *                       group.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder disableScaleIn(java.lang.Boolean disableScaleIn) {
            this.disableScaleIn = disableScaleIn;
            return this;
        }

        /**
         * Sets the value of {@link NetworkUtilizationScalingProps#getEstimatedInstanceWarmup}
         * @param estimatedInstanceWarmup Estimated time until a newly launched instance can send metrics to CloudWatch.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder estimatedInstanceWarmup(software.amazon.awscdk.core.Duration estimatedInstanceWarmup) {
            this.estimatedInstanceWarmup = estimatedInstanceWarmup;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link NetworkUtilizationScalingProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public NetworkUtilizationScalingProps build() {
            return new Jsii$Proxy(targetBytesPerSecond, cooldown, disableScaleIn, estimatedInstanceWarmup);
        }
    }

    /**
     * An implementation for {@link NetworkUtilizationScalingProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements NetworkUtilizationScalingProps {
        private final java.lang.Number targetBytesPerSecond;
        private final software.amazon.awscdk.core.Duration cooldown;
        private final java.lang.Boolean disableScaleIn;
        private final software.amazon.awscdk.core.Duration estimatedInstanceWarmup;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.targetBytesPerSecond = this.jsiiGet("targetBytesPerSecond", java.lang.Number.class);
            this.cooldown = this.jsiiGet("cooldown", software.amazon.awscdk.core.Duration.class);
            this.disableScaleIn = this.jsiiGet("disableScaleIn", java.lang.Boolean.class);
            this.estimatedInstanceWarmup = this.jsiiGet("estimatedInstanceWarmup", software.amazon.awscdk.core.Duration.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final java.lang.Number targetBytesPerSecond, final software.amazon.awscdk.core.Duration cooldown, final java.lang.Boolean disableScaleIn, final software.amazon.awscdk.core.Duration estimatedInstanceWarmup) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.targetBytesPerSecond = java.util.Objects.requireNonNull(targetBytesPerSecond, "targetBytesPerSecond is required");
            this.cooldown = cooldown;
            this.disableScaleIn = disableScaleIn;
            this.estimatedInstanceWarmup = estimatedInstanceWarmup;
        }

        @Override
        public java.lang.Number getTargetBytesPerSecond() {
            return this.targetBytesPerSecond;
        }

        @Override
        public software.amazon.awscdk.core.Duration getCooldown() {
            return this.cooldown;
        }

        @Override
        public java.lang.Boolean getDisableScaleIn() {
            return this.disableScaleIn;
        }

        @Override
        public software.amazon.awscdk.core.Duration getEstimatedInstanceWarmup() {
            return this.estimatedInstanceWarmup;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("targetBytesPerSecond", om.valueToTree(this.getTargetBytesPerSecond()));
            if (this.getCooldown() != null) {
                data.set("cooldown", om.valueToTree(this.getCooldown()));
            }
            if (this.getDisableScaleIn() != null) {
                data.set("disableScaleIn", om.valueToTree(this.getDisableScaleIn()));
            }
            if (this.getEstimatedInstanceWarmup() != null) {
                data.set("estimatedInstanceWarmup", om.valueToTree(this.getEstimatedInstanceWarmup()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-autoscaling.NetworkUtilizationScalingProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            NetworkUtilizationScalingProps.Jsii$Proxy that = (NetworkUtilizationScalingProps.Jsii$Proxy) o;

            if (!targetBytesPerSecond.equals(that.targetBytesPerSecond)) return false;
            if (this.cooldown != null ? !this.cooldown.equals(that.cooldown) : that.cooldown != null) return false;
            if (this.disableScaleIn != null ? !this.disableScaleIn.equals(that.disableScaleIn) : that.disableScaleIn != null) return false;
            return this.estimatedInstanceWarmup != null ? this.estimatedInstanceWarmup.equals(that.estimatedInstanceWarmup) : that.estimatedInstanceWarmup == null;
        }

        @Override
        public int hashCode() {
            int result = this.targetBytesPerSecond.hashCode();
            result = 31 * result + (this.cooldown != null ? this.cooldown.hashCode() : 0);
            result = 31 * result + (this.disableScaleIn != null ? this.disableScaleIn.hashCode() : 0);
            result = 31 * result + (this.estimatedInstanceWarmup != null ? this.estimatedInstanceWarmup.hashCode() : 0);
            return result;
        }
    }
}

==> autoscaling-1.93.0-sources.jar: software/amazon/awscdk/services/autoscaling/NetworkUtilizationScalingProps.java <==
package software.amazon.awscdk.services.autoscaling;

/**
 * Properties for enabling scaling based on network utilization.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.24.0 (build b722f66)", date = "2021-03-11T13:47:04.992Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.autoscaling.$Module.class, fqn = "@aws-cdk/aws-autoscaling.NetworkUtilizationScalingProps")
@software.amazon.jsii.Jsii.Proxy(NetworkUtilizationScalingProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface NetworkUtilizationScalingProps extends software.amazon.jsii.JsiiSerializable, software.amazon.awscdk.services.autoscaling.BaseTargetTrackingProps {

    /**
     * Target average bytes/seconds on each instance.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.Number getTargetBytesPerSecond();

    /**
     * @return a {@link Builder} of {@link NetworkUtilizationScalingProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link NetworkUtilizationScalingProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<NetworkUtilizationScalingProps> {
        private java.lang.Number targetBytesPerSecond;
        private software.amazon.awscdk.core.Duration cooldown;
        private java.lang.Boolean disableScaleIn;
        private software.amazon.awscdk.core.Duration estimatedInstanceWarmup;

        /**
         * Sets the value of {@link NetworkUtilizationScalingProps#getTargetBytesPerSecond}
         * @param targetBytesPerSecond Target average bytes/seconds on each instance. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder targetBytesPerSecond(java.lang.Number targetBytesPerSecond) {
            this.targetBytesPerSecond = targetBytesPerSecond;
            return this;
        }

        /**
         * Sets the value of {@link NetworkUtilizationScalingProps#getCooldown}
         * @param cooldown Period after a scaling completes before another scaling activity can start.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder cooldown(software.amazon.awscdk.core.Duration cooldown) {
            this.cooldown = cooldown;
            return this;
        }

        /**
         * Sets the value of {@link NetworkUtilizationScalingProps#getDisableScaleIn}
         * @param disableScaleIn Indicates whether scale in by the target tracking policy is disabled.
         *                       If the value is true, scale in is disabled and the target tracking policy
         *                       won't remove capacity from the autoscaling group. Otherwise, scale in is
         *                       enabled and the target tracking policy can remove capacity from the
         *                       group.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder disableScaleIn(java.lang.Boolean disableScaleIn) {
            this.disableScaleIn = disableScaleIn;
            return this;
        }

        /**
         * Sets the value of {@link NetworkUtilizationScalingProps#getEstimatedInstanceWarmup}
         * @param estimatedInstanceWarmup Estimated time until a newly launched instance can send metrics to CloudWatch.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder estimatedInstanceWarmup(software.amazon.awscdk.core.Duration estimatedInstanceWarmup) {
            this.estimatedInstanceWarmup = estimatedInstanceWarmup;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link NetworkUtilizationScalingProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public NetworkUtilizationScalingProps build() {
            return new Jsii$Proxy(targetBytesPerSecond, cooldown, disableScaleIn, estimatedInstanceWarmup);
        }
    }

    /**
     * An implementation for {@link NetworkUtilizationScalingProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements NetworkUtilizationScalingProps {
        private final java.lang.Number targetBytesPerSecond;
        private final software.amazon.awscdk.core.Duration cooldown;
        private final java.lang.Boolean disableScaleIn;
        private final software.amazon.awscdk.core.Duration estimatedInstanceWarmup;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.targetBytesPerSecond = software.amazon.jsii.Kernel.get(this, "targetBytesPerSecond", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
            this.cooldown = software.amazon.jsii.Kernel.get(this, "cooldown", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.core.Duration.class));
            this.disableScaleIn = software.amazon.jsii.Kernel.get(this, "disableScaleIn", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
            this.estimatedInstanceWarmup = software.amazon.jsii.Kernel.get(this, "estimatedInstanceWarmup", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.core.Duration.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final java.lang.Number targetBytesPerSecond, final software.amazon.awscdk.core.Duration cooldown, final java.lang.Boolean disableScaleIn, final software.amazon.awscdk.core.Duration estimatedInstanceWarmup) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.targetBytesPerSecond = java.util.Objects.requireNonNull(targetBytesPerSecond, "targetBytesPerSecond is required");
            this.cooldown = cooldown;
            this.disableScaleIn = disableScaleIn;
            this.estimatedInstanceWarmup = estimatedInstanceWarmup;
        }

        @Override
        public final java.lang.Number getTargetBytesPerSecond() {
            return this.targetBytesPerSecond;
        }

        @Override
        public final software.amazon.awscdk.core.Duration getCooldown() {
            return this.cooldown;
        }

        @Override
        public final java.lang.Boolean getDisableScaleIn() {
            return this.disableScaleIn;
        }

        @Override
        public final software.amazon.awscdk.core.Duration getEstimatedInstanceWarmup() {
            return this.estimatedInstanceWarmup;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("targetBytesPerSecond", om.valueToTree(this.getTargetBytesPerSecond()));
            if (this.getCooldown() != null) {
                data.set("cooldown", om.valueToTree(this.getCooldown()));
            }
            if (this.getDisableScaleIn() != null) {
                data.set("disableScaleIn", om.valueToTree(this.getDisableScaleIn()));
            }
            if (this.getEstimatedInstanceWarmup() != null) {
                data.set("estimatedInstanceWarmup", om.valueToTree(this.getEstimatedInstanceWarmup()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-autoscaling.NetworkUtilizationScalingProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            NetworkUtilizationScalingProps.Jsii$Proxy that = (NetworkUtilizationScalingProps.Jsii$Proxy) o;

            if (!targetBytesPerSecond.equals(that.targetBytesPerSecond)) return false;
            if (this.cooldown != null ? !this.cooldown.equals(that.cooldown) : that.cooldown != null) return false;
            if (this.disableScaleIn != null ? !this.disableScaleIn.equals(that.disableScaleIn) : that.disableScaleIn != null) return false;
            return this.estimatedInstanceWarmup != null ? this.estimatedInstanceWarmup.equals(that.estimatedInstanceWarmup) : that.estimatedInstanceWarmup == null;
        }

        @Override
        public final int hashCode() {
            int result = this.targetBytesPerSecond.hashCode();
            result = 31 * result + (this.cooldown != null ? this.cooldown.hashCode() : 0);
            result = 31 * result + (this.disableScaleIn != null ? this.disableScaleIn.hashCode() : 0);
            result = 31 * result + (this.estimatedInstanceWarmup != null ? this.estimatedInstanceWarmup.hashCode() : 0);
            return result;
        }
    }
}
